{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 2,
                    "ramMin": 8000
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/fastqc:0.11.8"
                }
            ],
            "baseCommand": [
                "fastqc",
                "-t",
                "2",
                "--extract",
                "-k",
                "7"
            ],
            "inputs": [
                {
                    "type": "string",
                    "default": ".",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-o"
                    },
                    "label": "",
                    "doc": "",
                    "id": "#fastqc.cwl/output_postfix"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "label": "",
                    "doc": "",
                    "id": "#fastqc.cwl/reads"
                }
            ],
            "id": "#fastqc.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*/fastqc_report.html"
                    },
                    "id": "#fastqc.cwl/output_qc_report"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*/fastqc_data.txt"
                    },
                    "id": "#fastqc.cwl/output_qc_stats"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "$(inputs.newname + inputs.suffix)",
                            "entry": "$(inputs.srcfile)"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "baseCommand": "true",
            "inputs": [
                {
                    "type": "string",
                    "id": "#rename.cwl/newname"
                },
                {
                    "type": "File",
                    "id": "#rename.cwl/srcfile"
                },
                {
                    "type": "string",
                    "id": "#rename.cwl/suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.newname + inputs.suffix)"
                    },
                    "id": "#rename.cwl/outfile"
                }
            ],
            "id": "#rename.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/reads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/step_rename_report/outfile",
                    "id": "#main/output_qc_report"
                },
                {
                    "type": "File",
                    "outputSource": "#main/step_rename_stats/outfile",
                    "id": "#main/output_qc_stats"
                }
            ],
            "steps": [
                {
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/reads",
                            "id": "#main/step_fastqc/reads"
                        }
                    ],
                    "out": [
                        "#main/step_fastqc/output_qc_report",
                        "#main/step_fastqc/output_qc_stats"
                    ],
                    "id": "#main/step_fastqc"
                },
                {
                    "run": "#rename.cwl",
                    "in": [
                        {
                            "source": "#main/reads",
                            "valueFrom": "${ return self.nameroot + \".fastqc_report\"; }",
                            "id": "#main/step_rename_report/newname"
                        },
                        {
                            "source": "#main/step_fastqc/output_qc_report",
                            "id": "#main/step_rename_report/srcfile"
                        },
                        {
                            "default": ".html",
                            "id": "#main/step_rename_report/suffix"
                        }
                    ],
                    "out": [
                        "#main/step_rename_report/outfile"
                    ],
                    "id": "#main/step_rename_report"
                },
                {
                    "run": "#rename.cwl",
                    "in": [
                        {
                            "source": "#main/reads",
                            "valueFrom": "${ return self.nameroot + \".fastqc_data\"; }",
                            "id": "#main/step_rename_stats/newname"
                        },
                        {
                            "source": "#main/step_fastqc/output_qc_stats",
                            "id": "#main/step_rename_stats/srcfile"
                        },
                        {
                            "default": ".txt",
                            "id": "#main/step_rename_stats/suffix"
                        }
                    ],
                    "out": [
                        "#main/step_rename_stats/outfile"
                    ],
                    "id": "#main/step_rename_stats"
                }
            ],
            "doc": "This workflow takes in single-end reads, and performs the following steps in order:\ndemux_se.cwl (does not actually demux for single end, but mirrors the paired-end processing protocol)\n",
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
